FormeChoiceChip<T extends Object> class

example

FormeChoiceChip<String>(
     validator:
        FormeValidates.notNull(errorText: 'choice required'),
     items: "123456789"
         .characters
         .map((e) => FormeChipItem(label: Text(e), data: e))
         .toList(),
     name: 'choice',
     decorator: FormeInputDecorationDecorator(
       childBuilder: (context, child) {
         return Padding(
           padding: const EdgeInsets.symmetric(
               vertical: 8, horizontal: 5),
           child: child,
         );
       },
       decorationBuilder: (context) {
         return const InputDecoration(labelText: "Choice Chip");
       },
     ),
  )

Inheritance

Constructors

FormeChoiceChip({Key? key, String? name, T? initialValue, FormeAsyncValidator<T?>? asyncValidator, Duration? asyncValidatorDebounce, AutovalidateMode? autovalidateMode, FormeFieldDecorator<T?>? decorator, bool enabled = true, FocusNode? focusNode, FormeFieldInitialized<T?>? onInitialized, FormeFieldSetter<T?>? onSaved, FormeFieldStatusChanged<T?>? onStatusChanged, int? order, bool quietlyValidate = false, bool readOnly = false, bool requestFocusOnUserInteraction = true, FormeFieldValidationFilter<T?>? validationFilter, FormeValidator<T?>? validator, InputDecoration? decoration, EdgeInsets? padding, ChipThemeData? chipThemeData, Axis direction = Axis.horizontal, WrapAlignment alignment = WrapAlignment.start, WrapAlignment runAlignment = WrapAlignment.start, double runSpacing = 0.0, double spacing = 0.0, WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, required List<FormeChipItem<T>> items})

Properties

alignment → WrapAlignment
final
asyncValidator → FormeAsyncValidator<T?>?
used to perform an async validation
finalinherited
asyncValidatorDebounce → Duration?
not worked when validate manually
finalinherited
autovalidateMode → AutovalidateMode
finalinherited
builder → FormeFieldBuilder<T?>
finalinherited
chipThemeData → ChipThemeData?
final
crossAxisAlignment → WrapCrossAlignment
final
decoration → InputDecoration?
final
decorator → FormeFieldDecorator<T?>?
used to decorate field
finalinherited
direction → Axis
final
enabled → bool
whether field is enabled,
finalinherited
fieldType → Type
no setterinherited
focusNode → FocusNode?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initialValue → T?
initial value
finalinherited
items → List<FormeChipItem<T>>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
name → String?
field name
finalinherited
onInitialized → FormeFieldInitialized<T?>?
called immediately after FormeFieldState.initStatus
finalinherited
onSaved → FormeFieldSetter<T?>?
finalinherited
onStatusChanged → FormeFieldStatusChanged<T?>?
listen field status change
finalinherited
order → int?
used to support Forme.autovalidateByOrder
finalinherited
padding → EdgeInsets?
final
quietlyValidate → bool
quietlyValidate
finalinherited
readOnly → bool
finalinherited
requestFocusOnUserInteraction → bool
whether request focus when field value changed
finalinherited
runAlignment → WrapAlignment
final
runSpacing → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
final
textDirection → TextDirection?
final
validationFilter → FormeFieldValidationFilter<T?>?
used to determine whether perform a validation
finalinherited
validator → FormeValidator<T?>?
sync validator
finalinherited
verticalDirection → VerticalDirection
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FormeFieldState<T?>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited