FormeDateTimeFieldState class

Inheritance

Constructors

FormeDateTimeFieldState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
enabled ↔ bool
set field enable or not
getter/setter pairinherited
errorText ↔ String?
get errorText
getter/setter pairinherited
focusNode → FocusNode
get current widget's focus node or create a new one
no setterinherited
form → FormeState?
get form state
no setterinherited
hasFocus → bool
whether field has been focused
no setterinherited
hasFocusNode → bool
whether field has a focusnode
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initialValue → DateTime?
get initialValue
no setterinherited
isCustomValidation → bool
whether current validation is set via errorText
no setterinherited
isNullable → bool
whether value can be nullable or not
no setterinherited
isValueChanged → bool
whether value is changed after initialed
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
name → String?
no setterinherited
oldValue → FormeOptional<DateTime?>?
get previous value
no setterinherited
order → int?
no setterinherited
readOnly ↔ bool
set field readonly or not
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPicker → VoidCallback?
no setter
status → FormeFieldStatus<DateTime?>
get current status
no setterinherited
type → Type
get generic type
no setterinherited
validation → FormeFieldValidation
get current validation state
no setterinherited
value ↔ DateTime?
equals to FormeFieldState.didChange
getter/setter pairinherited-setter
widget → FormeDateTimeField
The current configuration.
no setteroverride

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addVisitor(FormeFieldVisitor<DateTime?> visitor) → bool
add visitor
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChange(DateTime? newValue) → void
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant FormeField<DateTime?> oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
initStatus() → void
this method will be called only once in state's lifecircle,immediately called after initState
inherited
isValueEquals(DateTime? oldValue, DateTime? newValue) → bool
is value equals
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onStatusChanged(FormeFieldChangedStatus<DateTime?> status) → void
override this method if you want to listen status changed
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeVisitor(FormeFieldVisitor<DateTime?> visitor) → bool
remove visitor
inherited
requestFocus() → void
inherited
requestFocusOnUserInteraction() → void
request focus if user interacted
inherited
reset() → void
reset field
inherited
save() → void
save field
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
unfocus() → void
inherited
validate({bool quietly = false}) → Future<FormeFieldValidateSnapshot<DateTime?>>
this method is used to manually validate
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited