FormeSwitch class

Inheritance

Constructors

FormeSwitch({Key? key, String? name, bool initialValue = false, FormeAsyncValidator<bool>? asyncValidator, Duration? asyncValidatorDebounce, AutovalidateMode? autovalidateMode, bool enabled = true, FocusNode? focusNode, FormeFieldInitialized<bool>? onInitialized, FormeFieldSetter<bool>? onSaved, FormeFieldStatusChanged<bool>? onStatusChanged, int? order, bool quietlyValidate = false, bool readOnly = false, bool requestFocusOnUserInteraction = true, FormeFieldValidationFilter<bool>? validationFilter, FormeValidator<bool>? validator, FormeFieldDecorator<bool>? decorator, Color? activeColor, Color? activeTrackColor, Color? inactiveThumbColor, Color? inactiveTrackColor, ImageProvider<Object>? activeThumbImage, ImageProvider<Object>? inactiveThumbImage, MaterialStateProperty<Color?>? thumbColor, MaterialStateProperty<Color?>? trackColor, DragStartBehavior? dragStartBehavior, MaterialTapTargetSize? materialTapTargetSize, Color? focusColor, Color? hoverColor, MaterialStateProperty<Color?>? overlayColor, double? splashRadius, ImageErrorListener? onActiveThumbImageError, ImageErrorListener? onInactiveThumbImageError, bool autofocus = false, MaterialStateProperty<Icon?>? thumbIcon, MouseCursor? mouseCursor})

Properties

activeColor → Color?
final
activeThumbImage → ImageProvider<Object>?
final
activeTrackColor → Color?
final
asyncValidator → FormeAsyncValidator<bool>?
used to perform an async validation
finalinherited
asyncValidatorDebounce → Duration?
not worked when validate manually
finalinherited
autofocus → bool
final
autovalidateMode → AutovalidateMode
finalinherited
builder → FormeFieldBuilder<bool>
finalinherited
decorator → FormeFieldDecorator<bool>?
used to decorate field
finalinherited
dragStartBehavior → DragStartBehavior?
final
enabled → bool
whether field is enabled,
finalinherited
fieldType → Type
no setterinherited
focusColor → Color?
final
focusNode → FocusNode?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hoverColor → Color?
final
inactiveThumbColor → Color?
final
inactiveThumbImage → ImageProvider<Object>?
final
inactiveTrackColor → Color?
final
initialValue → bool
initial value
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTapTargetSize → MaterialTapTargetSize?
final
mouseCursor → MouseCursor?
final
name → String?
field name
finalinherited
onActiveThumbImageError → ImageErrorListener?
final
onInactiveThumbImageError → ImageErrorListener?
final
onInitialized → FormeFieldInitialized<bool>?
called immediately after FormeFieldState.initStatus
finalinherited
onSaved → FormeFieldSetter<bool>?
finalinherited
onStatusChanged → FormeFieldStatusChanged<bool>?
listen field status change
finalinherited
order → int?
used to support Forme.autovalidateByOrder
finalinherited
overlayColor → MaterialStateProperty<Color?>?
final
quietlyValidate → bool
quietlyValidate
finalinherited
readOnly → bool
finalinherited
requestFocusOnUserInteraction → bool
whether request focus when field value changed
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splashRadius → double?
final
thumbColor → MaterialStateProperty<Color?>?
final
thumbIcon → MaterialStateProperty<Icon?>?
final
trackColor → MaterialStateProperty<Color?>?
final
validationFilter → FormeFieldValidationFilter<bool>?
used to determine whether perform a validation
finalinherited
validator → FormeValidator<bool>?
sync validator
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FormeFieldState<bool>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited